#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.

"""  Codifies capability request states, queue states,
and execution priorites """

from __future__ import annotations

from enum import Enum

# pylint: disable=C0103


class CapabilityRequestState(Enum):
    """
    Enum that specifies the states that a capability request can be in
    """

    Complete = 0
    Submitted = 1
    Created = 2
    Cancelled = 3
    Failed = 4


class QueueState(Enum):
    """
    Enum that specifies the state that an execution is in as it relates to the queue
    """

    NotQueued = 0
    Queued = 1
    Running = 2


class ExecutionPriority(Enum):
    """
    Enum that specifies the priority of a particular capability execution

    TODO: These numbers are just placeholders I added on a whim, and I think this Enum should get another look in
        the future
    """

    High = 25
    Default = 50
    Low = 100
